==> idp-saml-impl-4.2.1-sources.jar: net/shibboleth/idp/saml/audit/impl/ProxyCountAuditExtractor.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.shibboleth.idp.saml.audit.impl;

import java.util.function.Function;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import org.opensaml.profile.context.ProfileRequestContext;
import org.opensaml.saml.common.SAMLObject;
import org.opensaml.saml.saml2.core.ProxyRestriction;

/**
 * {@link Function} that returns {@link ProxyRestriction#getProxyCount()}.
 * 
 * @since 4.2.0
 */
public class ProxyCountAuditExtractor extends AbstractProxyRestrictionAuditExtractor<Integer> {
    
    /**
     * Constructor.
     *
     * @param strategy lookup strategy for message
     */
    public ProxyCountAuditExtractor(
            @Nonnull final Function<ProfileRequestContext,SAMLObject> strategy) {
        super(strategy);
    }

    /** {@inheritDoc} */
    @Override
    @Nullable protected Integer doApply(@Nullable final ProxyRestriction condition) {
        if (condition != null) {
            return condition.getProxyCount();
        }
        
        return null;
    }
    
}

==> idp-saml-impl-5.1.5-sources.jar: net/shibboleth/idp/saml/audit/impl/ProxyCountAuditExtractor.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.shibboleth.idp.saml.audit.impl;

import java.util.function.Function;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import org.opensaml.profile.context.ProfileRequestContext;
import org.opensaml.saml.common.SAMLObject;
import org.opensaml.saml.saml2.core.ProxyRestriction;

/**
 * {@link Function} that returns {@link ProxyRestriction#getProxyCount()}.
 * 
 * @since 4.2.0
 */
public class ProxyCountAuditExtractor extends AbstractProxyRestrictionAuditExtractor<Integer> {
    
    /**
     * Constructor.
     *
     * @param strategy lookup strategy for message
     */
    public ProxyCountAuditExtractor(@Nonnull final Function<ProfileRequestContext,SAMLObject> strategy) {
        super(strategy);
    }

    /** {@inheritDoc} */
    @Override
    @Nullable protected Integer doApply(@Nullable final ProxyRestriction condition) {
        if (condition != null) {
            return condition.getProxyCount();
        }
        
        return null;
    }
    
}
